# Baseline Attacks

::: agentdojo.attacks.baseline_attacks.DirectAttack
    options:
        filters: ["!attack"]
        heading_level: 2

::: agentdojo.attacks.baseline_attacks.IgnorePreviousAttack
    options:
        filters: ["!attack"]
        heading_level: 2

::: agentdojo.attacks.baseline_attacks.SystemMessageAttack
    options:
        filters: ["!attack"]
        heading_level: 2

::: agentdojo.attacks.baseline_attacks.InjecAgentAttack
    options:
        filters: ["!attack"]
        heading_level: 2

::: agentdojo.attacks.important_instructions_attacks.ImportantInstructionsAttack
    options:
        filters: ["!attack"]
        heading_level: 2

::: agentdojo.attacks.important_instructions_attacks.ToolKnowledgeAttack
    options:
        filters: ["!attack"]
        heading_level: 2
